import { HttpClient } from '@angular/common/http';
import { PrestConfig } from './angular-prest.config';
import { Observable } from 'rxjs/Observable';
import 'rxjs/add/operator/map';
/**
 * Type of url params that can be passed to pRest
 */
export declare type PrestUrlParams = string | {
    [name: string]: string;
} | null;
/**
 * Type accepted for the request
 */
export declare type PrestRequestMethod = 'POST' | 'PUT' | 'PATH' | 'DELETE' | 'GET';
/**
 * AngualrPrestService is responsible to manage all requests
 * between the Angular aplication and the pRest API
 */
export declare class AngularPrestService {
    private http;
    private config;
    constructor(http: HttpClient, config: PrestConfig);
    /**
     * Get the token stored inside local storage
     * @returns string
     */
    private _getToken();
    /**
     * Create the request options
     * @param params PrestUrlParams
     * @returns object
     */
    private _getRequestOptions(params?);
    /**
     * Create a URL to make the request
     * @param table string
     * @returns string
     */
    private _getUrl(table);
    /**
     * Make GET request and return only one row of data or null
     * @param table string
     * @param params PrestUrlParams
     * @returns Observable<any>
     */
    get(table: string, params: PrestUrlParams): Observable<any>;
    /**
     * Make GET request and returns a list of data or null
     * @param table string
     * @param params PrestUrlParams
     * @returns Observable<any>
     */
    list(table: string, params?: PrestUrlParams): Observable<any>;
    /**
     * Make PATCH request and return the object updated
     * @param table string
     * @param data any
     * @param params PrestUrlParams
     * @returns Observable<any>
     */
    update(table: string, data: any, params: PrestUrlParams): Observable<any>;
    /**
     * Make POST request and return the server response or empty
     * @param table string
     * @param data any
     * @param params PrestUrlParams
     * @returns Observable<any>
     */
    create(table: string, data: any, params?: PrestUrlParams): Observable<any>;
    /**
     * Make DELETE request and return the server response or empty
     * @param table string
     * @param params PrestUrlParams
     * @returns Observable<any>
     */
    delete(table: string, params: PrestUrlParams): Observable<any>;
    /**
     * Create a custom query and send to the server
     * @param type PrestRequestMethod
     * @param url string
     * @param data any
     * @returns Observable<any>
     */
    customQuery(type: PrestRequestMethod, url: string, data?: any): Observable<any>;
}
